@@ -11,8 +11,9 @@ to plot the mass spectrum and decay chains.
 The current release supports SLHA version 1. Assistance with supporting version
 2 will be gladly accepted!
 
-The plotting script provides output in a source form usable in LaTeX documents
-or the Rivet make-plots system. Direct processing to PDF is planned.
+The plotting script provides output in PDF via LaTeX and the TikZ graphics package,
+as LaTeX/TikZ source for direct embedding into documents, and in the format used by
+the Rivet make-plots system.
 
 TODOs:
  * Identify HERWIG decay matrix element to use in ISAWIG
@@ -22,7 +23,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "0.6.1"
+__version__ = "1.0.1"
 
 
 def _autotype(var):
